@@ -1,5 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
+ * Copyright (C) 2003-2007 Imendio AB
  * Copyright (C) 2007 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
@@ -16,7 +17,7 @@
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- * 
+ *
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
@@ -263,6 +264,10 @@ empathy_log_manager_get_dates (EmpathyLogManager *manager,
 			continue;
 		}
 
+		if (!g_regex_match_simple ("\\d{8}", date, 0, 0)) {
+			continue;
+		}
+
 		dates = g_list_insert_sorted (dates, date, (GCompareFunc) strcmp);
 	}
 
@@ -325,7 +330,7 @@ empathy_log_manager_get_messages_for_file (EmpathyLogManager *manager,
 		EmpathyMessage     *message;
 		EmpathyContact     *sender;
 		gchar              *time;
-		EmpathyTime         t;
+		time_t              t;
 		gchar              *sender_id;
 		gchar              *sender_name;
 		gchar              *body;
@@ -523,7 +528,7 @@ empathy_log_manager_search_free (GList *hits)
 gchar *
 empathy_log_manager_get_date_readable (const gchar *date)
 {
-	EmpathyTime t;
+	time_t t;
 
 	t = empathy_time_parse (date);
 
@@ -634,24 +639,22 @@ log_manager_get_dir (EmpathyLogManager *manager,
 {
 	const gchar *account_id;
 	gchar       *basedir;
-	gchar       *str;
 
 	account_id = mc_account_get_unique_name (account);
-	basedir = 
-	str = g_build_path (G_DIR_SEPARATOR_S,
-			    log_manager_get_basedir (manager),
-			    account_id,
-			    chat_id,
-			    NULL);
 
 	if (chatroom) {
 		basedir = g_build_path (G_DIR_SEPARATOR_S,
-					str,
+					log_manager_get_basedir (manager),
+					account_id,
 					LOG_DIR_CHATROOMS,
+					chat_id,
 					NULL);
-		g_free (str);
 	} else {
-		basedir = str;
+		basedir = g_build_path (G_DIR_SEPARATOR_S,
+					log_manager_get_basedir (manager),
+					account_id,
+					chat_id,
+					NULL);
 	}
 
 	return basedir;
@@ -701,7 +704,7 @@ log_manager_get_filename_for_date (EmpathyLogManager *manager,
 static gchar *
 log_manager_get_timestamp_filename (void)
 {
-	EmpathyTime  t;
+	time_t      t;
 	gchar      *time_str;
 	gchar      *filename;
 
@@ -717,7 +720,7 @@ log_manager_get_timestamp_filename (void)
 static gchar *
 log_manager_get_timestamp_from_message (EmpathyMessage *message)
 {
-	EmpathyTime t;
+	time_t t;
 
 	t = empathy_message_get_timestamp (message);
 
