@@ -384,7 +384,7 @@ tp_group_get_local_pending_cb (DBusGProxy *proxy,
 	EmpathyTpGroup     *group = user_data;
 	EmpathyTpGroupPriv *priv = GET_PRIV (group);
 	GArray             *handles;
-	guint               i;
+	guint               i = 0;
 	
 	if (error) {
 		empathy_debug (DEBUG_DOMAIN, "Failed to get local pendings: %s",
@@ -394,6 +394,7 @@ tp_group_get_local_pending_cb (DBusGProxy *proxy,
 	}
 
 	handles = g_array_sized_new (FALSE, FALSE, sizeof (guint), 1);
+	g_array_append_val (handles, i);
 	for (i = 0; array->len > i; i++) {
 		GValueArray        *pending_struct;
 		const gchar        *message;
@@ -407,7 +408,7 @@ tp_group_get_local_pending_cb (DBusGProxy *proxy,
 		reason = g_value_get_uint (g_value_array_get_nth (pending_struct, 2));
 		message = g_value_get_string (g_value_array_get_nth (pending_struct, 3));
 
-		g_array_insert_val (handles, 0, member_handle);
+		g_array_index (handles, guint, 0) = member_handle;
 		tp_group_members_changed_cb (priv->group_iface,
 					     message,      /* message */
 					     NULL,         /* added */
@@ -565,7 +566,7 @@ empathy_tp_group_new (McAccount *account,
 	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
 
 	group_iface = tp_chan_get_interface (tp_chan,
-					     TELEPATHY_CHAN_IFACE_GROUP_QUARK);
+					     TP_IFACE_QUARK_CHANNEL_INTERFACE_GROUP);
 	g_return_val_if_fail (group_iface != NULL, NULL);
 
 	group = g_object_new (EMPATHY_TYPE_TP_GROUP, NULL);
